betty.core module - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.core module

Provide tools to build core application components.

class betty.core.CoreComponent

  Bases: `ABC`

  A core component.

  Core components can manage their resources by being bootstrapped and shut down.

  This is internal. It MAY be used anywhere in Betty’s source code, but MUST NOT be used by third-party code.

  Parameters:

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  __init__(*args: Any, **kwargs: Any)
    Parameters:

      - args (`typing.Any`)

      - kwargs (`typing.Any`)

  async bootstrap() → None

    Bootstrap the component.

    Return type:

      `None`

  async shutdown() → None

    Shut the component down.

    Return type:

      `None`